<?php declare (strict_types = 1);

namespace Infomaker\Everyware\NewsML;

use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use Infomaker\Everyware\Support\NewRelicLog;
use Infomaker\Everyware\NewsML\Parsers\IdfParser;
use Exception;
use SimpleXMLIterator;

class NewsMLTransformer
{

    public const VALID_TAG_IDF = 'idf';
    public const VALID_TAG_OBJECT = 'object';
    public const VALID_TAG_META = 'metadata';

    /**
     * @var IdfParser
     */
    private $parser;

    public function __construct(ItemParser $parser)
    {
        $this->parser = $parser;
    }

    public function transform($newsml): array
    {
        try {
            $iterator = new SimpleXMLIterator($newsml);

            if ($iterator->getName() === static::VALID_TAG_IDF || $iterator->getName() === static::VALID_TAG_OBJECT || $iterator->getName() === static::VALID_TAG_META) {
                return $this->parser->parse($iterator);
            }

            return [];
        } catch (Exception $exception) {
            NewRelicLog::error(sprintf('Failed parsing NewsML from %s', $newsml), $exception);
        }
    }
}
