<?php declare (strict_types = 1);

namespace Infomaker\Everyware\NewsML;

use Infomaker\Everyware\NewsML\Parsers\ElementParser;
use Infomaker\Everyware\NewsML\Parsers\GroupParser;
use Infomaker\Everyware\NewsML\Parsers\MetaDataParser;
use Infomaker\Everyware\NewsML\Parsers\IdfParser;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use Infomaker\Everyware\NewsML\Parsers\ObjectParser;

class NewsMLTransformerManager
{

    /**
     * Contains all registered Parsers
     *
     * @var ItemParser[]
     */
    private static $parsers = [];

    private function __construct()
    { }

    public static function registerObjectParser(string $type, ItemParser $parser): void
    {
        static::$parsers[$type] = $parser;
    }

    public static function createTransformer(): NewsMLTransformer
    {
        $elementParser = new ElementParser();
        $objectParser = new ObjectParser(static::$parsers);
        $groupParser = new GroupParser($elementParser, $objectParser);
        $idfParser = new IdfParser($elementParser, $objectParser, $groupParser);

        return new NewsMLTransformer($idfParser);
    }

    public static function createObjectTransformer(): NewsMLTransformer
    {
        return new NewsMLTransformer(new ObjectParser(static::$parsers));
    }

    public static function createMetaDataTransformer(): NewsMLTransformer
    {
        $objectParser = new ObjectParser(static::$parsers);

        return new NewsMLTransformer(new MetaDataParser($objectParser));
    }
}
