<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use SimpleXMLIterator;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;

/**
 * ElementParser
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\NewsML\Parsers
 * @since   Infomaker\Everyware\NewsML\Parsers\ElementParser 1.0.0
 */
class ElementParser implements ItemParser
{
    public const TAG = 'element';

    /**
     * Contains a list of inline elements allowed to pass through the filter
     *
     * @var array
     */
    protected $allowedTags = [
        'span',
        'i',
        'b',
        'em',
        'strong',
        'sup',
        'sub',
        'br',
        'hr',
        'a',
        'script',
        'iframe',
        'mark'
    ];

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);
        $item->fill([
            'type' => $item->getType(),
            'content' => $item->getFilteredContent($this->allowedTags)
        ]);
        return [$item];
    }
}
