<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\IframelyParser;
use Infomaker\Everyware\NewsML\Item;
use PhpSpec\ObjectBehavior;

class IframelyParserSpec extends ObjectBehavior
{
    function it_is_initializable()
    {
        $this->shouldHaveType(IframelyParser::class);
    }
    
    public function it_should_parse_an_element()
    {
        $xml = '<object id="iframely-e98933e6ea201687a18ee90e6a362188" type="x-im/iframely" url="iframely-url">
            <data>
                <title>Title</title>
                <embedCode>Content</embedCode>
            </data>
            <links>
                <link rel="alternate" type="text/html" title="Title" url="iframely-url">
                    <data>
                        <description>Description</description>
                        <provider>Provider</provider>
                    </data>
                </link>
                <link rel="alternate" type="image/jpg" url="iframely-image">
                    <data>
                        <width>1024</width>
                        <height>768</height>
                    </data>
                </link>
            </links>
        </object>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');

        $this->parse($el)
            ->shouldHaveArrayKey([
                'id' => 'iframely-e98933e6ea201687a18ee90e6a362188',
                'type' => 'x-im/iframely',
                'url' => 'iframely-url',
                'content' => 'Content',
                'links' => [
                    [
                        'url' => 'iframely-url',
                        'type' => 'text/html',
                        'data' => [
                            'description' => 'Description',
                            'provider' => 'Provider'
                        ]
                    ],
                    [
                        'url' => 'iframely-image',
                        'type' => 'image/jpg',
                        'data' => [
                            'width' => '1024',
                            'height' => '768'
                        ]
                    ]
                ]
            ]);
    }

    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/iframely');
    }
    
    public function getMatchers(): array
    {
        return [
            'haveArrayKey' => function ($subject, $values) {
                return ($subject[0]->getItemAttributes() == $values) && ($subject[0] instanceof Item);
            },
        ];
    }
}
