<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\SocialEmbedParser;
use PhpSpec\ObjectBehavior;
use Infomaker\Everyware\NewsML\Item;
use Prophecy\Argument;

class SocialEmbedParserSpec extends ObjectBehavior
{
    function it_is_initializable()
    {
        $this->shouldHaveType(SocialEmbedParser::class);
    }
    public function it_should_parse_a_instagram_element()
    {
        $xml = '<xml><links><link type="x-im/instagram" url="instagram">test</link></links></xml>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveUrl('embed_url', 'https://api.instagram.com/oembed/?url=instagram');
    }
    public function it_should_parse_a_facebook_element()
    {
        $xml = '<xml><links><link type="x-im/facebook-post" url="facebook">test</link></links></xml>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveUrl('url', 'facebook');
    }
    public function it_should_parse_a_twitter_element()
    {
        $xml = '<xml><links><link type="x-im/tweet" url="twitter">test</link></links></xml>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveUrl('url', 'twitter');
    }
    public function it_should_parse_a_vimeo_element()
    {
        $xml = '<xml><links><link type="x-im/vimeo" url="vimeo">test</link></links></xml>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveUrl('url', 'vimeo');
    }
    public function it_should_parse_all_elements()
    {
        $xml = '
            <xml>
                <links>
                    <link type="x-im/instagram" url="instagram">test</link>
                    <link type="x-im/facebook-post" url="facebook">test</link>
                    <link type="x-im/tweet" url="twitter">test</link>
                    <link type="x-im/vimeo" url="vimeo">test</link>
                </links>
            </xml>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveUrls(['embed_url', 'url', 'url', 'url'], ['https://api.instagram.com/oembed/?url=instagram', 'facebook', 'twitter', 'vimeo']);
    }
    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/socialembed');
    }
    public function getMatchers(): array
    {
        return [
            'haveUrl' => function ($subject, string $property, string $value) {
                $content = $subject[0]->getItemAttribute('content');
                return ($content[0][$property] === $value) || ($content[0] instanceof Item);
            },
            'haveUrls' => function ($subject, array $property, array $values) {
                $content = $subject[0]->getItemAttribute('content');
                foreach ($content as $key => $item) {
                    if(($item[$property[$key]] !== $values[$key]) || (! $item instanceof Item)) {
                        return false;
                    }
                }
                return true;
            },

        ];
    }
}
//newsmlitem
